==> v0.2.2.zip: console/README.md <==
# Dragonfly Console

[![GitHub release](https://img.shields.io/github/release/dragonflyoss/console.svg)](https://github.com/dragonflyoss/console/releases)
[![LICENSE](https://img.shields.io/github/license/dragonflyoss/console.svg?style=flat-square)](https://github.com/dragonflyoss/console/blob/main/LICENSE)
[![Coverage](https://codecov.io/gh/dragonflyoss/console/branch/main/graph/badge.svg)](https://app.codecov.io/gh/dragonflyoss/console)

## Introduction

Dragonfly console is the front-end console of dragonfly,
through which you can easily configure clusters and view cluster information.

## Functionality Overview

- **Scheduler Cluster:**  Manage the scheduler cluster and configure the information of the scheduler cluster.

- **Seed Peer Cluster:**  Manage the seed peer cluster and configure the seed peer cluster information.

- **Security:**  Manage security groups and security rules,
  users can configure the security groups associated with the scheduler cluster.

- **Permissions:**  Manage permissions and roles.

- **Task:**  Manage asynchronous tasks, including preheat tasks.

- **User:**  Manage user information, you can change user roles here.

## Documentation

You can find the full documentation on the [d7y.io][d7y.io].

## Community

Join the conversation and help the community.

- **Slack Channel**: [#dragonfly](https://cloud-native.slack.com/messages/dragonfly/) on [CNCF Slack](https://slack.cncf.io/)
- **Discussion Group**: <dragonfly-discuss@googlegroups.com>
- **Developer Group**: <dragonfly-developers@googlegroups.com>
- **Twitter**: [@dragonfly_oss](https://twitter.com/dragonfly_oss)
- **DingTalk**: [22880028764](https://qr.dingtalk.com/action/joingroup?code=v1,k1,pkV9IbsSyDusFQdByPSK3HfCG61ZCLeb8b/lpQ3uUqI=&_dt_no_comment=1&origin=11)

[d7y.io]: https://d7y.io/

## Contributing

You should check out our [CONTRIBUTING](./CONTRIBUTING.md) and develop the project together.

==> v0.2.6.zip: console/README.md <==
# Dragonfly Console

[![GitHub release](https://img.shields.io/github/release/dragonflyoss/console.svg)](https://github.com/dragonflyoss/console/releases)
[![LICENSE](https://img.shields.io/github/license/dragonflyoss/console.svg?style=flat-square)](https://github.com/dragonflyoss/console/blob/main/LICENSE)
[![Coverage](https://codecov.io/gh/dragonflyoss/console/branch/main/graph/badge.svg)](https://app.codecov.io/gh/dragonflyoss/console)

## Introduction

Dragonfly console is the front-end console of dragonfly,
through which you can easily configure clusters and view cluster information.

## Functionality Overview

- **Scheduler Cluster:**  Manage the scheduler cluster and configure the information of the scheduler cluster.

- **Seed Peer Cluster:**  Manage the seed peer cluster and configure the seed peer cluster information.

- **Security:**  Manage security groups and security rules,
  users can configure the security groups associated with the scheduler cluster.

- **Permissions:**  Manage permissions and roles.

- **Task:**  Manage asynchronous tasks, including preheat tasks.

- **User:**  Manage user information, you can change user roles here.

## Documentation

You can find the full documentation on the [d7y.io][d7y.io].

## Community

Join the conversation and help the community.

- **Slack Channel**: [#dragonfly](https://cloud-native.slack.com/messages/dragonfly/) on [CNCF Slack](https://slack.cncf.io/)
- **Github Discussions**: [Dragonfly Discussion Forum](https://github.com/dragonflyoss/dragonfly/discussions)
- **Developer Group**: <dragonfly-developers@googlegroups.com>
- **Maintainer Group**: <dragonfly-maintainers@googlegroups.com>
- **Twitter**: [@dragonfly_oss](https://twitter.com/dragonfly_oss)
- **DingTalk**: [22880028764](https://qr.dingtalk.com/action/joingroup?code=v1,k1,pkV9IbsSyDusFQdByPSK3HfCG61ZCLeb8b/lpQ3uUqI=&_dt_no_comment=1&origin=11)

[d7y.io]: https://d7y.io/

## Contributing

You should check out our [CONTRIBUTING](./CONTRIBUTING.md) and develop the project together.
